<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Application Proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy Type</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Address</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Optional</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Save</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Invalid IP address</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Invalid port</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Disconnect</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Save</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connecting</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Disconnect</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Are you sure you want to delete this configuration?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Wired Connection %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Wireless Connection %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE Connection %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>New VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN Type</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Export</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Network</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Application Proxy</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Personal Hotspot</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Network Details</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>System Proxy</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Wired Network</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Wireless Network</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Airplane Mode</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Wired Network Adapter</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Add Network Connection</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Wireless Network Adapter</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Connect to hidden network</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Create PPPoE Connection</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN Status</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Create VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Import VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy Type</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Configuration URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Address</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Create Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primary DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Speed</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Airplane Mode</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Invalid DNS address</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Not Bind</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Device MAC Addr</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Cloned MAC Addr</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Customize MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>The name already exists</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Auto Connect</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Add Settings</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Create Hotspot</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP Address</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Duplicate IP address</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Invalid IP address</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Invalid netmask</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Only one gateway is allowed</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Invalid gateway</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Duplicate IP address</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Invalid IP address</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Only one gateway is allowed</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Invalid gateway</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignore</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Address</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Only applied in corresponding resources</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Method</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Invalid IP address</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Invalid netmask</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Invalid gateway</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Network</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP conflict</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Method</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignore</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Network Details</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>System Proxy</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Application Proxy</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Airplane Mode</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Network Details</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Network</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP conflict</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Disabled</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Configure by Network Manager</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Personal Hotspot</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Service</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Refuse EAP Authentication</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Refuse PAP Authentication</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Refuse CHAP Authentication</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Refuse MSCHAP Authentication</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Refuse MSCHAPv2 Authentication</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>No BSD Data Compression</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>No Deflate Data Compression</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>No TCP Header Compression</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>No Protocol Field Compression</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>No Address/Control Compression</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Send PPP Echo Packets</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Use MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Create PPPoE Connection</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>System Proxy</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Save</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy Type</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Optional</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP Proxy</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignore the proxy configurations for the above hosts and domains</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Configuration URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Security</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunneled TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Protected EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Save password for this user</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Save password for all users</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Ask me always</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Disabled</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonymous</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Authenticated</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Both</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatic</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Version 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Version 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Auth</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identity</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Options</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Private Key</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>User Cert</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonymous ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provisioning</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC file</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Inner Auth</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP Version</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Private Pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Invalid password</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Security</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Key</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Security Required</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Invalid password</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Shared key</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Open system</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Security</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Authentication</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Key</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Advanced</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Customize Gateway Port</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Gateway Port</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Customize Renegotiation Interval</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Renegotiation Interval</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Use LZO Data Compression</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Use TCP Connection</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Use TAP Device</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Customize Tunnel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Customize UDP Fragment Size</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP Fragment Size</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restrict Tunnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Randomize Remote Hosts</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Advanced</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (default)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Secure (default)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Weak</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T When Available (default)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T Always</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Disabled</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2 (default)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (default)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domain</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Vendor</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Encryption</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT Traversal Mode</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Group</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Forward Secrecy</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Local Port</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Disable Dead Peer Detection</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Enable IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Group Name</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Group ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pre-Shared Key</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1 Algorithms</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Phase2 Algorithms</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Invalid gateway</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Allow Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD Script</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>User Cert</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Private Key</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Use FSID for Key Passphrase</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Invalid gateway</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificates (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificates with Password (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Static Key</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Saved</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Ask</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Not Required</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Auth Type</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>User Cert</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Private Key</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Options</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Private Pwd</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Customize Key Direction</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Key Direction</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Remote IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Local IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>All Available (default)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (less secure)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (most secure)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Refuse EAP Authentication</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Refuse PAP Authentication</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Refuse CHAP Authentication</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Refuse MSCHAP Authentication</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Refuse MSCHAPv2 Authentication</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>No BSD Data Compression</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>No Deflate Data Compression</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>No TCP Header Compression</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>No Protocol Field Compression</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>No Address/Control Compression</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Send PPP Echo Packets</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Use MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Security</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN Status</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Create VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Import VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Import Error</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>File error</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Not Required</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy Type</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Retry Indefinitely When Failed</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA File</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignore Certificate Warnings</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Use TLS Hostname Extensions</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN Security</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cipher</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Invalid gateway</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Saved</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Ask</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Not Required</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Options</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT Domain</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Invalid gateway</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Private Key</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH Agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Smart Card</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pre-Shared Key</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Auth Type</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>User Cert</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Request an Inner IP Address</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Enforce UDP Encapsulation</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Use IP Compression</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Enable Custom Cipher Proposals</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS Authentication</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Subject Match</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Remote Cert Type</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Key File</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Customize Key Direction</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Key Direction</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Invalid gateway</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Saved</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Ask</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Not Required</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Pwd Options</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Group Name</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Group Pwd</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Use Hybrid Authentication</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA File</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Plug in the network cable first</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Wired Network Adapter</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Add Network Connection</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Select Settings</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Wireless Network Adapter</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Close Hotspot</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Disable hotspot first if you want to connect to a wireless network</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Connect to hidden network</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Not Bind</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Required</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Device MAC Addr</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Customize MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Security Type</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Channel</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Band</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primary DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Speed</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Device disabled</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connected but no Internet access</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Not connected</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Network cable unplugged</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connecting</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Authenticating</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obtaining IP address</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connected</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Disconnected</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP conflict</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Failed</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtaining address</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Wired Network</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Wired Network %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Wireless Network</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Wireless Network %1</translation>
    </message>
</context>
</TS>